BonBoxplot <-
  function(data,
           Xlab = "",
           axis_titl = "",
           titl = "",
           pair = F,
           logscale = F) {
    ## Make Boxplots with Holm bonferroni adjusted P-values
    
    ## calculate pvalues ----
    pvalues <- c()
    for (i in 1:(ncol(data) - 1)) {
      pvalues[i] <-
        t.test(data[(data$Type == "PLB"), i], data[(data$Type =="NAB"), i], paired = pair, na.action =na.omit)$p.value
    }
    
    ## melt data frame ----
    data <- melt(data)
    if (logscale) {
      data$value <- log10(data$value)
    }
    
    ## Define 'max' as the y-location where the label needs to be placed ----
    max <- rep(0, length = nlevels(data$variable))
    for (i in 1:length(max)) {
      Lev <- levels(data()$variable)[i]
      Bool <- (data$variable == levels(data$variable)[i])
      max[i] <- max(data$value[Bool], na.rm = TRUE)
      ifelse(max[i] < 0, max[i] * 0.5, max[i] * 1.5)
      
    }
    
    ## Define data matrix for the labels, containing the variable, the y-location of the label (max) and the p-value ----
    labels <- cbind.data.frame(max, pvalues, levels(data$variable))
    colnames(labels) <- c("max", "pvalues", "variable")
    
    ## Add adjusted Bonferroni correction p-values and identify significant parameters ----
    bonferroni <- labels[order(labels$pvalues),]
    for (i in 1:nrow(bonferroni)) {
      bonferroni$adjbon[i] <- 0.05 / (nrow(bonferroni) - i + 1)
      bonferroni$signifi[i] <- bonferroni$pvalues[i] < bonferroni$adjbon[i]
    }
    bonferroni2 <- bonferroni[order(as.numeric(rownames(bonferroni))),]
    
    data$Legend <- factor(data$Type, levels = c("PLB", "NAB"))
    
    
    ##excel write
    
    write.xlsx(bonferroni2, paste0(output.dir, titl, ".xlsx"), )
    ## Plot and save ----
    
    ggplot(data, aes(variable, value)) +
      geom_boxplot(aes(fill = Legend)) +
      geom_point(position = position_dodge(width = 0.75),
                 size = 0.75,
                 aes(group = Legend)) +
      scale_fill_viridis_d(begin = 0.5) +
      geom_text(
        data = bonferroni2,
        aes(
          label = paste0("p = ", format(round(pvalues, 3), nsmall = 3)),
          x = variable,
          y = max
        ),
        size = 3,
        fontface = ifelse(bonferroni2$signifi == T, "bold", "plain")
      ) +
      xlab(Xlab) +
      ylab(axis_titl) +
      # ggtitle(file.name)+
      theme_bw()
    
    
    ggsave(
      filename = paste0(output.dir, titl, ".png"),
      width = 154,
      height = 100,
      units = "mm",
      dpi = 300
    )
    
    
  }
