BonBoxplot_sens <-
  function(data,
           Xlab = "",
           axis_titl = "",
           titl = "test",
           pair = F,
           logscale = F) {
    ## Make Boxplots with Holm bonferroni adjusted P-values
    
    names(data) <- c("value", "Type", "Legend")
    data_PLB <- data[data$Type == "PLB", ]
    data_NAB <- data[data$Type == "NAB", ]
    
    ## calculate pvalues ----
    pvalues <- c()
    
    pvalues[1] <-
      t.test(data_PLB[(data_PLB$Legend == "Fresh"), 1], data_PLB[(data_PLB$Legend ==
                                                                    "Aged"), 1], paired = pair)$p.value
    
    pvalues[2] <-
      t.test(data_NAB[(data_NAB$Legend == "Fresh"), 1], data_NAB[(data_NAB$Legend ==
                                                                    "Aged"), 1], paired = pair)$p.value
    
    pvalues <- as.data.frame(pvalues)
    pvalues$Type <- c("PLB", "NAB")
    
    
    if (logscale) {
      data$value <- log10(data$value)
    }
    
    
    
    ## Add adjusted Bonferroni correction p-values and identify significant parameters ----
    test <- pvalues[order(pvalues$pvalues),]
    for (i in 1:nrow(pvalues)) {
      test$adjbon[i] <- 0.055 / (nrow(test) - i + 1)
      test$signifi[i] <- test$pvalues[i] < test$adjbon[i]
    }
    test2 <- test[order(as.numeric(rownames(test))),]
    
    data$Legend <- factor(data$Legend, levels = c("Fresh", "Aged"))
    data$Type <- factor(data$Type, levels = c("PLB", "NAB"))
    
    
    ## Plot and save ----
    
    ggplot(data, aes(Type, value)) +
      geom_boxplot(aes(fill = Legend)) +
      geom_point(position = position_dodge(width = 0.75),
                 size = 0.75,
                 aes(group = Legend)) +
      scale_fill_viridis_d(begin = 0.5) +
      geom_text(
        data = pvalues,
        aes(
          label = paste0("p = ", format(round(pvalues, 4), nsmall = 4)),
          x = Type,
          y = 7
        ),
        size = 3,
        fontface = ifelse(test2$signifi == T, "bold", "plain")
      ) +
      xlab(Xlab) +
      ylab(axis_titl) +
      ylim(0, 8) +
      theme_bw()
    
    
    
    ggsave(
      filename = paste0(output.dir, titl, ".png"),
      width = 154,
      height = 100,
      units = "mm",
      dpi = 300
    )
    
    
  }
