PCbiplot_all <-
  function(PC,
           x = "PC1",
           y = "PC2",
           titl = "" ,
           compound_class) {
    #make a principal component biplot
    
    # PC being a prcomp object
    
    #Colour coding
    
    for (i in 1:length(compound_class)) {
      if (compound_class[i] == "standard analyses")
        compound_class[i] = "#365C8DFF"
      else if (compound_class[i] == "amino acids")
        compound_class[i] = "#440154FF"
      else if (compound_class[i] == "Sugars")
        compound_class[i] = "#1FA187FF"
      else if (compound_class[i] == "bitter acids")
        compound_class[i] = "#ED7014"
      else if (compound_class[i] == "aroma")
        compound_class[i] = "#9FDA3AFF"
      else if (compound_class[i] == "aldehydes")
        compound_class[i] = "#DCE319FF"
      else
        compound_class[i] = "#482677FF"
    }
    
    # Calculating explained variance
    PC_out     <- as.data.frame(PC$x)
    vars_out   <- apply(PC_out, 2, var)
    vars_out   <- round(vars_out / sum(vars_out) * 100, 1)
    percentage <-
      paste0(colnames(PC_out), " (", paste0(as.character(vars_out), "%", ")"))
    
    # Extract data from the samples
    data <- data.frame(names = row.names(PC$x), PC$x)
    
    # Extract data from variables
    datapc <- data.frame(names = rownames(PC$rotation), PC$rotation)
    
    # Scaling the variables to match well on the plot
    mult <- min((max(data[, y]) - min(data[, y]) / (max(datapc[, y]) - min(datapc[, y]))),
                (max(data[, x]) - min(data[, x]) / (max(datapc[, x]) - min(datapc[, x]))))
    datapc <- transform(datapc,
                        v1 = 1.5 * mult * (get(x)),
                        v2 = 1.5 * mult * (get(y)))
    
    # Clean up data and combine
    
    data$v1 <- NA
    data$v2 <- NA
    data$Type <- "PLB"
    data[grep("0", data$names), "Type"] <- "NAB"
    data$Class <- "Observation"
    data$CompoundClass <- NA
    
    data.trans <-
      data[, c("names", x, y, "Class", "Type", "CompoundClass")]
    
    
    datapc$Class <- "Variable"
    datapc$Type <- NA
    datapc$CompoundClass <- compound_class
    
    datapc.trans <-
      datapc[, c("names", "v1", "v2", "Class", "Type", "CompoundClass")]
    
    colnames(datapc.trans)[2:3] <- c(x, y)
    
    data.comb <- rbind.data.frame(data.trans, datapc.trans)
    data.comb$Freshness <- "Fresh"
    data.comb$Freshness[grep("_A", rownames(data.comb))] <- "Aged"
    data.comb$Freshness[data.comb$Class == "Variable"] <- NA
    
    data.comb$names <- gsub("_F", "", data.comb$names)
    data.comb$names <- gsub("_A", "", data.comb$names)
    
    ## Plot scores
    theme_set(theme_classic())
    ggplot(data.comb, aes_string(x = x, y = y)) +
      geom_hline(yintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_vline(xintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_point(
        data = data.comb[which(data.comb$Type == "PLB"),],
        size = 2.5,
        colour = ifelse(data.comb[which(data.comb$Type == "PLB"), "Freshness"] == "Fresh",
                        "grey50",
                        "#5E2C04")
      ) +
      geom_point(
        data = data.comb[which(data.comb$Type == "NAB"),],
        size = 2.5,
        colour = ifelse(data.comb[which(data.comb$Type == "NAB"), "Freshness"] == "Fresh",
                        "grey",
                        "#9A7B4F")
      ) +
      scale_colour_viridis_d(name = "Legend") +
      # geom_point(
      #   data = data.comb[which(data.comb$Class == "Variable"), ],
      #   size = 2,
      #
      # ) +
      
      geom_text_repel(
        data = data.comb[which(data.comb$Class == "Observation"),],
        size = 3.5,
        aes(label = names),
        fontface = "plain",
        color = ifelse(
          data.comb[data.comb$Class == "Observation", ]$Freshness == "Fresh",
          ifelse(data.comb[data.comb$Class == "Observation", ]$Type == "PLB", "grey50", "grey"),
          ifelse(data.comb[data.comb$Class == "Observation", ]$Type == "PLB", "#5E2C04", "#9A7B4F")
        ),
        # bg.color = ifelse(data.comb$Class == "Observation", "black", "grey30"),
        # bg.r = 0.10,
        max.overlaps = 100,
        force = 5
      ) +
      theme(
        axis.text = element_text(size = 10),
        axis.title = element_text(size = 12),
        title = element_text(size = 14)
      ) +
      xlab(percentage[1]) +
      ylab(percentage[2]) +
      xlim(-10, 10)
    ylim(-10, 5)
    
    
    
    
    ggsave(
      filename = paste0(output.dir, titl, "scores", ".png"),
      width = 154,
      height = 100,
      units = "mm",
      dpi = 300
    )
    
    ## Plot loadings
    theme_set(theme_classic())
    ggplot(data.comb, aes_string(x = x, y = y)) +
      geom_hline(yintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_vline(xintercept = 0,
                 size = .1,
                 lty = 2) +
      
      scale_colour_viridis_d(name = "Legend") +
      geom_point(data = data.comb[which(data.comb$Class == "Variable"),],
                 size = 2,
                 colour = compound_class) +
      
      geom_text_repel(
        data = data.comb[which(data.comb$Class == "Variable"),],
        size = 2,
        aes(label = names),
        colour = compound_class,
        # fontface=ifelse(data.comb$Class == "Observation", "bold", "plain"),
        
        # bg.color = ifelse(data.comb$Class == "Observation", "black", "grey30"),
        # bg.r = 0.10,
        max.overlaps = 100,
        force = 5,
        segment.color = NA
      ) +
      theme(
        axis.text = element_text(size = 10),
        axis.title = element_text(size = 12),
        title = element_text(size = 14)
      ) +
      xlab(percentage[1]) +
      ylab(percentage[2]) +
      xlim(-10, 10)
    ylim(-10, 5)
    
    ggsave(
      filename = paste0(output.dir, titl, "loadings", ".png"),
      width = 154,
      height = 100,
      units = "mm",
      dpi = 300
    )
    
    
    
  }