PLSRplot_OAS <-
  function(Xmatrix,
           Ymatrix,
           Yname = "",
           x = "Comp.1",
           y = "Comp.2",
           titl = "",
           compound_class) {
    file.name <- substring(titl, regexpr(" ", titl) + 1, nchar(titl))
    file.name <- gsub(" ", "_", file.name)
    
    # Make a PLSR plot
    
    
    #Colour coding
    
    for (i in 1:length(compound_class)) {
      if (compound_class[i] == "standard analyses")
        compound_class[i] = "#365C8DFF"
      else if (compound_class[i] == "amino acids")
        compound_class[i] = "#440154FF"
      else if (compound_class[i] == "Sugars")
        compound_class[i] = "#1FA187FF"
      else if (compound_class[i] == "bitter acids")
        compound_class[i] = "#ED7014"
      else if (compound_class[i] == "aroma")
        compound_class[i] = "#9FDA3AFF"
      else if (compound_class[i] == "aldehydes")
        compound_class[i] = "#DCE319FF"
      else
        compound_class[i] = "#482677FF"
    }
    
    Xmatrix <- as.matrix(Xmatrix)
    Ymatrix <- as.matrix(Ymatrix)
    colnames(Ymatrix) <- Yname
    rownames(Ymatrix) <- rownames(Xmatrix)
    
    #Scale Ymatrix
    for (i in 1:ncol(Ymatrix)) {
      Ymatrix[, i] <- Ymatrix[, i] / sd(Ymatrix[, i])
    }
    
    #perform PLSR
    PLSR <-
      plsr(
        Ymatrix ~ Xmatrix,
        scale = TRUE ,
        validation = "CV",
        method = "kernelpls",
        na.action = na.omit
      )
    
    # Calculating explained variance
    percentage1 <- round(PLSR$Xvar[1] / PLSR$Xtotvar * 100, 1)
    percentage2 <- round(PLSR$Xvar[2] / PLSR$Xtotvar * 100, 1)
    A <- drop(R2(PLSR, estimate = "train", intercept = FALSE)$val)
    percentage1Y <- round(mean(A[1]) * 100, 1)
    percentage2Y <- round(mean(A[2] - A[1]) * 100, 1)
    
    percentage1 <-
      paste0("Factor 1",
             " (",
             paste0(as.character(percentage1)),
             "%, ",
             paste0(as.character(percentage1Y)),
             "%)")
    percentage2 <-
      paste0("Factor 2",
             " (",
             paste0(as.character(percentage2)),
             "%, ",
             paste0(as.character(percentage2Y)),
             "%)")
    
    # Extract data from the samples
    scores <-
      data.frame(names = row.names(PLSR$scores[, 1:2]), PLSR$scores[, 1:2])
    
    # Extract data from variables
    analytics <-
      data.frame(names = row.names(PLSR$loadings[, 1:2]), PLSR$loadings[, 1:2])
    a <- drop(PLSR$Yloadings)
    sensorics <- data.frame(rownames(PLSR$Yloadings), c(a[1]), c(a[2]))
    
    rownames(sensorics) <- Yname
    colnames(sensorics) <- colnames(analytics)
    sensorics$names <- Yname
    
    
    # Clean up data and combine
    
    scores$Type <- "PLB"
    scores[grep("0", scores$names), "Type"] <- "NAB"
    scores$Class <- "Observation"
    scores$Aged <- "fresh"
    scores[grep("A$", scores$names), "Aged"] <- "aged"
    
    analytics$Class <- "Analytics"
    analytics$Type <- NA
    sensorics$Class <- "Sensorics"
    sensorics$Type <- NA
    
    loadings.comb <- rbind.data.frame(analytics, sensorics)
    scores$names <- gsub("_F|_A", "", rownames(scores))
    
    ## Plot scores
    theme_set(theme_classic())
    ggplot(scores, aes_string(x = "Comp.1", y = "Comp.2")) +
      geom_hline(yintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_vline(xintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_point(
        data = scores[which(scores$Type == "PLB"), 2:3],
        size = 2.5,
        colour = ifelse(scores[which(scores$Type == "PLB"), "Aged"] == "fresh",
                        "grey50",
                        "#5E2C04")
      ) +
      geom_point(
        data = scores[which(scores$Type == "NAB"),],
        size = 2.5,
        colour = ifelse(scores[which(scores$Type == "NAB"), "Aged"] == "fresh",
                        "grey",
                        "#9A7B4F")
      ) +
      scale_colour_viridis_d(name = "Legend") +
      geom_text_repel(
        data = scores[which(scores$Type == "PLB"), ],
        size = 3.5,
        aes(label = names),
        fontface = "plain",
        colour = ifelse(scores[which(scores$Type == "PLB"), "Aged"] == "fresh",
                        "grey50",
                        "#5E2C04"),
        # color = ifelse(data.comb[data.comb$Class == "Observation",]$Freshness == "Fresh", ifelse(data.comb[data.comb$Class == "Observation",]$Type== "PLB","grey50","grey"),ifelse(data.comb[data.comb$Class == "Observation",]$Type== "PLB","#5E2C04","#9A7B4F")),
        max.overlaps = 100,
        force = 5
      ) +
      geom_text_repel(
        data = scores[which(scores$Type == "NAB"), ],
        size = 3.5,
        aes(label = names),
        fontface = "plain",
        colour = ifelse(scores[which(scores$Type == "NAB"), "Aged"] == "fresh",
                        "grey",
                        "#9A7B4F"),
        # color = ifelse(data.comb[data.comb$Class == "Observation",]$Freshness == "Fresh", ifelse(data.comb[data.comb$Class == "Observation",]$Type== "PLB","grey50","grey"),ifelse(data.comb[data.comb$Class == "Observation",]$Type== "PLB","#5E2C04","#9A7B4F")),
        max.overlaps = 100,
        force = 5
      ) +
      theme(
        axis.text = element_text(size = 10),
        axis.title = element_text(size = 12),
        title = element_text(size = 14)
      ) +
      xlab(percentage1) +
      ylab(percentage2)
    
    
    
    
    ggsave(
      filename = paste0(output.dir, titl, "scores", ".png"),
      width = 154,
      height = 100,
      units = "mm",
      dpi = 300
    )
    loadings.comb
    
    
    ## Plot loadings
    theme_set(theme_classic())
    
    ggplot(loadings.comb, aes_string(x = x, y = y)) +
      geom_hline(yintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_vline(xintercept = 0,
                 size = .1,
                 lty = 2) +
      geom_point(
        data = loadings.comb[, 2:3],
        size = 2,
        colour = ifelse(loadings.comb[, "Class"] == "Analytics",
                        compound_class,
                        "black")
      ) +
      geom_text_repel(
        size = ifelse(loadings.comb$Class == "Sensorics",  2, 2),
        aes(label = names),
        fontface = ifelse(loadings.comb$Class == "Sensorics", "bold", "plain"),
        color = ifelse(loadings.comb$Class == "Sensorics", "black", compound_class),
        # bg.color = ifelse(loadings.comb$Class == "Sensorics", "black", "grey30"),
        # bg.r = 0.10,
        max.overlaps = 100,
        force = 5,
        segment.color = NA
      ) +
      theme(
        axis.text = element_text(size = 10),
        axis.title = element_text(size = 12),
        title = element_text(size = 14)
      ) +
      xlab(percentage1) +
      ylab(percentage2)
    
    
    
    ggsave(
      filename = paste0(output.dir, titl, "loadings", ".png"),
      width = 154,
      height = 100,
      units = "mm",
      dpi = 300
    )
    
    
    
  }