volcano.plot <- function(data1,
                         data2,
                         qcutoff = 0.05,
                         titl = "",
                         pi0 = NULL) {
  
  ## make a volcano plot
  p.vector <- vector()
  p.temp <- vector()
  
  ## Paired t-tests
  for (i in 2:ncol(data1)) {
    p.temp <- t.test(
      as.numeric(data1[, i]),
      as.numeric(data2[, i]),
      paired = T,
      na.action = na.omit
      
    )$p.value
    
    p.vector <- c(p.vector, p.temp)
  }
  ## Calculating qvalues, and log2fold changes
  q.vector <- qvalue(as.numeric(p.vector), pi0 = pi0)$qval
  q.plot <- -nthroot(as.numeric(q.vector), 10)
  logfold <- log2(colMeans(data2[,-1] / data1[,-1], na.rm = TRUE))
  
  ## Combining all data in dataframe
  volcano.table <-
    data.frame(cbind(c(logfold),
                     c(p.vector),
                     c(q.vector),
                     c(q.plot)))
  
  names(volcano.table) <-
    c("log_FC", "p_value", "q_value", "q_plot")
  volcano.table$significant <- "no"
  
  ## Defining significant data
  volcano.table$significant[volcano.table$q_value <= qcutoff] <-
    "yes"
  
  ## Plot
  theme_set(theme_classic(base_family = "Poppins"))

  
  ggplot(volcano.table, mapping = aes(x = log_FC, y = q_plot)) +
    geom_vline(xintercept = 0,
               size = .1,
               lty = 2) +
    geom_point(size = 1,
               colour = "grey50") +
    geom_point(data = volcano.table[which(volcano.table$significant == "yes"), ],
               colour = "#1FA187FF",
               size = 1.5) +
    geom_text_repel(
      data = volcano.table[which(volcano.table$significant == "yes"), ],
      aes(label = rownames(volcano.table[which(volcano.table$significant ==
                                                 "yes"), ])),
      size = 2.5,
      color = "black",
      min.segment.length = 1,
      max.overlaps = Inf
      
    ) +
    
    
    ylab(expression(-~ "" ^ {
      10
    } ~ sqrt(adj. ~ italic(p) - Value))) +
    xlab(expression(log[2] ~ Fold ~ Change))
  
  ggsave(
    paste0(output.dir, titl, "_", as.character(qcutoff), ".png"),
    width = 154,
    height = 100,
    units = "mm",
    dpi = 300
  )
  
  ## Put results in excel
  write.xlsx(volcano.table,
             paste0(output.dir, titl, "_", as.character(qcutoff), ".xlsx"),
  )
  
  
  
  
}
